"""Unit tests for Plone i18n

References:
http://i18n.kde.org/translation-howto/check-gui.html#check-msgfmt
"""

try:
    import unittest,os,sys,commands,re
except ImportError:
    if os.name != 'posix':
        throw("The i18n tests only runs on posix systems, such as Linux, due to a dependency on Python's commands.getstatusoutput().")


class TestI18N(unittest.TestCase):

# This test isn't functional yet; msgfmt is pretty useless for automated testing until
# it can present the results in a simple machine-readable way. Now, the message varies
# in formatting depending on the results.
#
#    def testMsgFiles(self):
#        """Check that the .pot file is ok
#
#           "LC_ALL=C" is used so we don't get localised messages from msgfmt."""
#        status = commands.getstatusoutput('LC_ALL=C msgfmt --check --statistics ../plone.pot')
#        if status[0] != 0:
#            self.fail (status[1])

    def checkMsgExists(self,po,template):
        """Check that each existing message is translated and that there are no extra messages."""
        cmd='LC_ALL=C msgcmp --directory=.. %s %s' % (po,template)
        status = commands.getstatusoutput(cmd)
        if status[0] != 0:
            return (status[0],cmd)
        return None

    def testMsgExists(self):
        """Find all .po files and check them against the plone.pot"""
        files=os.listdir('..')
        regexp=re.compile('.*\.po$')
        failed=[]
        for filename in files:
            if regexp.match(filename) and filename != "plone-en.po":
                res=self.checkMsgExists(filename, 'plone.pot')
                if res!=None:
                    failed.append(res)
        if len(failed)!=0:
            msg=''
            for e in failed:
                msg=msg+'"%s" failed, exit code %s\n' % (e[1],e[0])
            self.fail(msg)

    def testNoDuplicateMsgId(self):
        """Check that there are no duplicate msgid:s in plone.pot"""
        cmd='grep ^msgid ../plone.pot|sort|uniq --repeated'
        status = commands.getstatusoutput(cmd)
        assert len(status[1])  == 0, "Duplicate msgid:s were found:\n\n%s" % status[1]

if __name__ == "__main__":
    unittest.main()
